@@ -1,5 +1,6 @@
 import gc
 import os
+import sys
 import atexit
 import signal
 import asyncio
@@ -82,7 +83,7 @@ class Base:
     '''
     def __init__(self):
         self.anitted = False
-        assert inspect.stack()[1].function == 'anit', 'Objects from Base must be constructed solely via "anit"'
+        assert sys._getframe(1).f_code.co_name == 'anit', 'Objects from Base must be constructed solely via "anit"'
 
     @classmethod
     async def anit(cls, *args, **kwargs):
@@ -128,8 +129,7 @@ class Base:
 
         self.isfini = False
         self.anitted = True  # For assertion purposes
-        self.finievt = None
-        self.entered = False
+        self.finievt = asyncio.Event()
 
         # hold a weak ref to other bases we should fini if they
         # are still around when we go down...
@@ -205,7 +205,6 @@ class Base:
 
     async def __aenter__(self):
         assert asyncio.get_running_loop() == self.loop
-        self.entered = True
         return self
 
     async def __aexit__(self, exc, cls, tb):
@@ -431,10 +430,7 @@ class Base:
         self._syn_funcs.clear()
         self._fini_funcs.clear()
 
-        fevt = self.finievt
-
-        if fevt is not None:
-            fevt.set()
+        self.finievt.set()
 
         return 0
 
@@ -468,13 +464,6 @@ class Base:
             base.waitfini(timeout=30)
 
         '''
-
-        if self.isfini:
-            return True
-
-        if self.finievt is None:
-            self.finievt = asyncio.Event()
-
         return await s_coro.event_wait(self.finievt, timeout)
 
     def schedCoro(self, coro):
