@@ -17,10 +17,10 @@ def normitem(item):
     return item
 
 def normdict(item):
-    return list(sorted([(normitem(key), normitem(val)) for key, val in item.items() if val is not None]))
+    return tuple(sorted([(normitem(key), normitem(val)) for key, val in item.items() if val is not None]))
 
 def normiter(item):
-    return list([normitem(i) for i in item if i is not None])
+    return tuple([normitem(i) for i in item if i is not None])
 
 normers = {
     dict: normdict,
