@@ -734,6 +734,19 @@ _reqValidPkgdefSchema = {
         'desc': {'type': 'string'},
         'svciden': {'type': ['string', 'null'], 'pattern': s_config.re_iden},
         'onload': {'type': 'string'},
+        'inits': {
+            'type': 'object',
+            'properties': {
+                'key': {'type': 'string'},
+                'versions': {
+                    'type': 'array',
+                    'items': {'$ref': '#/definitions/initdef'},
+                    'minItems': 1,
+                },
+            },
+            'additionalProperties': True,
+            'required': ['key', 'versions'],
+        },
         'author': {
             'type': 'object',
             'properties': {
@@ -803,10 +816,26 @@ _reqValidPkgdefSchema = {
                     'items': {'type': 'array',
                         'items': {'type': 'string'}},
                 },
+                'asroot:ondeny:import': {
+                    'type': 'string',
+                    'enum': ['allow', 'warn', 'deny'],
+                },
             },
             'additionalProperties': True,
             'required': ['name', 'storm']
         },
+        'initdef': {
+            'type': 'object',
+            'properties': {
+                'desc': {'type': 'string'},
+                'inaugural': {'type': 'boolean', 'default': False},
+                'name': {'type': 'string'},
+                'query': {'type': 'string'},
+                'version': {'type': 'integer', 'minimum': 0},
+            },
+            'additionalProperties': False,
+            'required': ['name', 'query', 'version']
+        },
         'apidef': {
             'type': 'object',
             'properties': {
@@ -925,6 +954,7 @@ _reqValidPkgdefSchema = {
                     'items': {'type': 'array',
                         'items': {'type': 'string'}},
                 },
+                'deprecated': {'$ref': '#/definitions/deprecatedItem'},
             },
             'additionalProperties': True,
             'required': ['name', 'storm']
@@ -951,6 +981,7 @@ _reqValidPkgdefSchema = {
                             'type': 'string',
                             'enum': s_msgpack.deepcopy(datamodel_basetypes),
                         },
+                        'deprecated': {'$ref': '#/definitions/deprecatedItem'},
                     },
                 }
             ],
