@@ -896,7 +896,7 @@ class LibModelMigrations(s_stormtypes.Lib, MigrationEditorMixin):
         'type': {'type': 'function', '_funcname': '_riskHasVulnToVulnerable',
                  'args': (
                       {'name': 'n', 'type': 'node', 'desc': 'The risk:hasvuln node to migrate.'},
-                      {'name': 'nodata', 'type': 'bool', 'default': False,
+                      {'name': 'nodata', 'type': 'boolean', 'default': False,
                        'desc': 'Do not copy nodedata to the risk:vulnerable node.'},
                  ),
                  'returns': {'type': 'list', 'desc': 'A list of idens for the risk:vulnerable nodes.'}}},
@@ -912,7 +912,7 @@ class LibModelMigrations(s_stormtypes.Lib, MigrationEditorMixin):
         'type': {'type': 'function', '_funcname': '_storm_query',
                  'args': (
                       {'name': 'n', 'type': 'node', 'desc': 'The inet:ssl:cert node to migrate.'},
-                      {'name': 'nodata', 'type': 'bool', 'default': False,
+                      {'name': 'nodata', 'type': 'boolean', 'default': False,
                        'desc': 'Do not copy nodedata to the inet:tls:servercert node.'},
                  ),
                  'returns': {'type': 'node', 'desc': 'The newly created inet:tls:servercert node.'}}},
@@ -1067,7 +1067,7 @@ class LibModelMigrations_0_2_31(s_stormtypes.Lib):
         {'name': 'listNodes', 'desc': 'Yield queued nodes.',
          'type': {'type': 'function', '_funcname': '_methListNodes',
                   'args': (
-                      {'name': 'form', 'type': 'form', 'default': None,
+                      {'name': 'form', 'type': 'str', 'default': None,
                        'desc': 'Only yield entries matching the specified form.'},
                       {'name': 'source', 'type': 'str', 'default': None,
                        'desc': 'Only yield entries that were seen by the specified source.'},
@@ -1076,12 +1076,12 @@ class LibModelMigrations_0_2_31(s_stormtypes.Lib):
                       {'name': 'size', 'type': 'int', 'default': None,
                        'desc': 'Only yield up to this many entries.'},
                   ),
-                  'returns': {'name': 'Yields', 'type': 'list',
+                  'returns': {'name': 'yields', 'type': 'list',
                               'desc': 'A tuple of (offset, form, valu, sources) values for the specified node.', }}},
         {'name': 'printNode', 'desc': 'Print detailed queued node information.',
          'type': {'type': 'function', '_funcname': '_methPrintNode',
                   'args': (
-                      {'name': 'offset', 'type': 'into', 'desc': 'The offset of the queued node to print.'},
+                      {'name': 'offset', 'type': 'int', 'desc': 'The offset of the queued node to print.'},
                   ),
                   'returns': {'type': 'null'}}},
         {'name': 'repairNode', 'desc': 'Repair a queued node.',
