@@ -136,26 +136,28 @@ class Triggers:
         finally:
             RecursionDepth.reset(token)
 
-    async def runNodeAdd(self, node):
+    async def runNodeAdd(self, node, useriden):
+        vars = {'auto': {'opts': {'user': useriden}}}
         with self._recursion_check():
-            [await trig.execute(node) for trig in self.nodeadd.get(node.form.name, ())]
+            [await trig.execute(node, vars=vars) for trig in self.nodeadd.get(node.form.name, ())]
 
-    async def runNodeDel(self, node):
+    async def runNodeDel(self, node, useriden):
+        vars = {'auto': {'opts': {'user': useriden}}}
         with self._recursion_check():
-            [await trig.execute(node) for trig in self.nodedel.get(node.form.name, ())]
+            [await trig.execute(node, vars=vars) for trig in self.nodedel.get(node.form.name, ())]
 
-    async def runPropSet(self, node, prop, oldv):
+    async def runPropSet(self, node, prop, oldv, useriden):
         vars = {'propname': prop.name, 'propfull': prop.full,
-                'auto': {'opts': {'propname': prop.name, 'propfull': prop.full, }},
+                'auto': {'opts': {'propname': prop.name, 'propfull': prop.full, 'user': useriden}},
                 }
         with self._recursion_check():
             [await trig.execute(node, vars=vars) for trig in self.propset.get(prop.full, ())]
             if prop.univ is not None:
                 [await trig.execute(node, vars=vars) for trig in self.propset.get(prop.univ.full, ())]
 
-    async def runTagAdd(self, node, tag):
+    async def runTagAdd(self, node, tag, useriden):
 
-        vars = {'tag': tag, 'auto': {'opts': {'tag': tag}}}
+        vars = {'tag': tag, 'auto': {'opts': {'tag': tag, 'user': useriden}}}
         with self._recursion_check():
 
             for trig in self.tagadd.get((node.form.name, tag), ()):
@@ -176,10 +178,10 @@ class Triggers:
                 for _, trig in globs.get(tag):
                     await trig.execute(node, vars=vars)
 
-    async def runTagDel(self, node, tag):
+    async def runTagDel(self, node, tag, useriden):
 
         vars = {'tag': tag,
-                'auto': {'opts': {'tag': tag}},
+                'auto': {'opts': {'tag': tag, 'user': useriden}},
                 }
         with self._recursion_check():
 
@@ -201,11 +203,11 @@ class Triggers:
                 for _, trig in globs.get(tag):
                     await trig.execute(node, vars=vars)
 
-    async def runEdgeAdd(self, n1, verb, n2):
+    async def runEdgeAdd(self, n1, verb, n2, useriden):
         n1form = n1.form.name if n1 else None
         n2form = n2.form.name if n2 else None
         n2iden = n2.iden() if n2 else None
-        varz = {'auto': {'opts': {'verb': verb, 'n2iden': n2iden}}}
+        varz = {'auto': {'opts': {'verb': verb, 'n2iden': n2iden, 'user': useriden}}}
         with self._recursion_check():
             cachekey = (n1form, verb, n2form)
             cached = self.edgeaddcache.get(cachekey)
@@ -251,11 +253,11 @@ class Triggers:
             for trig in cached:
                 await trig.execute(n1, vars=varz)
 
-    async def runEdgeDel(self, n1, verb, n2):
+    async def runEdgeDel(self, n1, verb, n2, useriden):
         n1form = n1.form.name if n1 else None
         n2form = n2.form.name if n2 else None
         n2iden = n2.iden() if n2 else None
-        varz = {'auto': {'opts': {'verb': verb, 'n2iden': n2iden}}}
+        varz = {'auto': {'opts': {'verb': verb, 'n2iden': n2iden, 'user': useriden}}}
         with self._recursion_check():
             cachekey = (n1form, verb, n2form)
             cached = self.edgedelcache.get(cachekey)
