@@ -29,10 +29,18 @@ class BaseModule(s_module.CoreModule):
 
             'types': (
 
+                ('meta:feed', ('guid', {}), {
+                    'doc': 'A data feed provided by a specific source.'}),
+
+                ('meta:feed:type:taxonomy', ('taxonomy', {}), {
+                    'interfaces': ('meta:taxonomy',),
+                    'doc': 'A data feed type taxonomy.'}),
+
                 ('meta:source', ('guid', {}), {
                     'doc': 'A data source unique identifier.'}),
 
                 ('meta:seen', ('comp', {'fields': (('source', 'meta:source'), ('node', 'ndef'))}), {
+                    'deprecated': True,
                     'doc': 'Annotates that the data in a node was obtained from or observed by a given source.'}),
 
                 ('meta:note', ('guid', {}), {
@@ -167,15 +175,31 @@ class BaseModule(s_module.CoreModule):
             'edges': (
                 ((None, 'refs', None), {
                     'doc': 'The source node contains a reference to the target node.'}),
+
                 (('meta:source', 'seen', None), {
                     'doc': 'The meta:source observed the target node.'}),
+
+                (('meta:feed', 'found', None), {
+                    'doc': 'The meta:feed produced the target node.'}),
+
                 (('meta:note', 'about', None), {
-                    'doc': 'The meta:note is about the target node.'
-                }),
+                    'doc': 'The meta:note is about the target node.'}),
+
                 (('meta:ruleset', 'has', 'meta:rule'), {
                     'doc': 'The meta:ruleset includes the meta:rule.'}),
+
+                (('meta:ruleset', 'has', 'inet:service:rule'), {
+                    'doc': 'The meta:ruleset includes the inet:service:rule.'}),
+
+                (('meta:ruleset', 'has', 'it:app:snort:rule'), {
+                    'doc': 'The meta:ruleset includes the it:app:snort:rule.'}),
+
+                (('meta:ruleset', 'has', 'it:app:yara:rule'), {
+                    'doc': 'The meta:ruleset includes the it:app:yara:rule.'}),
+
                 (('meta:rule', 'matches', None), {
                     'doc': 'The meta:rule has matched on target node.'}),
+
                 (('meta:rule', 'detects', None), {
                     'doc': 'The meta:rule is designed to detect instances of the target node.'}),
             ),
@@ -193,6 +217,9 @@ class BaseModule(s_module.CoreModule):
                     ('url', ('inet:url', {}), {
                         'doc': 'A URL which documents the meta source.'}),
 
+                    ('ingest:cursor', ('str', {}), {
+                        'doc': 'Used by ingest logic to capture the current ingest cursor within a feed.'}),
+
                     ('ingest:latest', ('time', {}), {
                         'doc': 'Used by ingest logic to capture the last time a feed ingest ran.'}),
 
@@ -210,6 +237,40 @@ class BaseModule(s_module.CoreModule):
 
                 )),
 
+                ('meta:feed:type:taxonomy', {}, ()),
+                ('meta:feed', {}, (
+
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
+                        'doc': 'A name for the feed.'}),
+
+                    ('type', ('meta:feed:type:taxonomy', {}), {
+                        'doc': 'The type of data feed.'}),
+
+                    ('source', ('meta:source', {}), {
+                        'doc': 'The meta:source which provides the feed.'}),
+
+                    ('url', ('inet:url', {}), {
+                        'doc': 'The URL of the feed API endpoint.'}),
+
+                    ('query', ('str', {}), {
+                        'doc': 'The query logic associated with generating the feed output.'}),
+
+                    ('opts', ('data', {}), {
+                        'doc': 'An opaque JSON object containing feed parameters and options.'}),
+
+                    ('period', ('ival', {}), {
+                        'doc': 'The time window over which results have been ingested.'}),
+
+                    ('latest', ('time', {}), {
+                        'doc': 'The time of the last record consumed from the feed.'}),
+
+                    ('offset', ('int', {}), {
+                        'doc': 'The offset of the last record consumed from the feed.'}),
+
+                    ('cursor', ('str', {'strip': True}), {
+                        'doc': 'A cursor used to track ingest offset within the feed.'}),
+                )),
+
                 ('meta:note:type:taxonomy', {}, ()),
                 ('meta:note', {}, (
 
