@@ -42,6 +42,20 @@ class ExecTeleCaller(s_cell.Cell):
             resp = await meth(*args, **kwargs)
             return resp
 
+class SpecialPathApi(s_cell.CellApi):
+    async def __anit__(self, cell, link, user, path):
+        await super().__anit__(cell, link, user)
+        self.path = path
+
+    async def getTestPath(self):
+        return self.path
+
+class PathAwareCell(s_cell.Cell):
+    async def getCellApi(self, link, user, path):
+        if not path:
+            return await self.cellapi.anit(self, link, user)
+        return await SpecialPathApi.anit(self, link, user, path)
+
 class AhaTest(s_test.SynTest):
 
     async def test_lib_aha_clone(self):
@@ -132,36 +146,36 @@ class AhaTest(s_test.SynTest):
 
     async def test_lib_aha_offon(self):
         with self.getTestDir() as dirn:
-            cryo0_dirn = s_common.gendir(dirn, 'cryo0')
+            cell0_dirn = s_common.gendir(dirn, 'cell0')
             async with self.getTestAha(dirn=dirn) as aha:
 
                 replaymult = 1
                 if s_common.envbool('SYNDEV_NEXUS_REPLAY'):
                     replaymult = 2
 
-                purl = await aha.addAhaSvcProv('0.cryo')
+                purl = await aha.addAhaSvcProv('0.cell')
 
                 wait00 = aha.waiter(1 * replaymult, 'aha:svcadd')
 
                 conf = {'aha:provision': purl}
-                async with self.getTestCryo(dirn=cryo0_dirn, conf=conf) as cryo:
+                async with self.getTestCell(dirn=cell0_dirn, conf=conf) as cell:
                     self.len(1 * replaymult, await wait00.wait(timeout=6))
 
-                    svc = await aha.getAhaSvc('0.cryo...')
+                    svc = await aha.getAhaSvc('0.cell...')
                     linkiden = svc.get('svcinfo', {}).get('online')
 
                     # Tear down the Aha cell.
                     await aha.__aexit__(None, None, None)
 
-            with self.getAsyncLoggerStream('synapse.lib.aha', f'Set [0.cryo.synapse] offline.') as stream:
+            with self.getAsyncLoggerStream('synapse.lib.aha', f'Set [0.cell.synapse] offline.') as stream:
                 async with self.getTestAha(dirn=dirn) as aha:
                     self.true(await asyncio.wait_for(stream.wait(), timeout=12))
-                    svc = await aha.getAhaSvc('0.cryo...')
+                    svc = await aha.getAhaSvc('0.cell...')
                     self.notin('online', svc.get('svcinfo'))
 
                     # Try setting something down a second time
-                    await aha.setAhaSvcDown('0.cryo', linkiden, network='synapse')
-                    svc = await aha.getAhaSvc('0.cryo...')
+                    await aha.setAhaSvcDown('0.cell', linkiden, network='synapse')
+                    svc = await aha.getAhaSvc('0.cell...')
                     self.notin('online', svc.get('svcinfo'))
 
     async def test_lib_aha_basics(self):
@@ -190,7 +204,7 @@ class AhaTest(s_test.SynTest):
 
         async with self.getTestAha() as aha:
 
-            cryo0_dirn = s_common.gendir(aha.dirn, 'cryo0')
+            cell0_dirn = s_common.gendir(aha.dirn, 'cell0')
 
             ahaurls = await aha.getAhaUrls()
 
@@ -200,76 +214,77 @@ class AhaTest(s_test.SynTest):
             if s_common.envbool('SYNDEV_NEXUS_REPLAY'):
                 replaymult = 2
 
-            conf = {'aha:provision': await aha.addAhaSvcProv('0.cryo')}
-            async with self.getTestCryo(dirn=cryo0_dirn, conf=conf) as cryo:
+            conf = {'aha:provision': await aha.addAhaSvcProv('0.cell')}
+            async with self.getTestCell(dirn=cell0_dirn, conf=conf) as cell:
 
                 await wait00.wait(timeout=2)
 
                 with self.raises(s_exc.NoSuchName):
                     await s_telepath.getAhaProxy({'host': 'hehe.haha'})
 
-                async with await s_telepath.openurl('aha://cryo...') as proxy:
+                async with await s_telepath.openurl('aha://cell...') as proxy:
                     self.nn(await proxy.getCellIden())
 
                 with self.raises(s_exc.BadArg):
-                    _proxy = await cryo.ahaclient.proxy(timeout=2)
-                    await _proxy.modAhaSvcInfo('cryo...', {'newp': 'newp'})
+                    _proxy = await cell.ahaclient.proxy(timeout=2)
+                    await _proxy.modAhaSvcInfo('cell...', {'newp': 'newp'})
 
-                async with await s_telepath.openurl('aha://0.cryo...') as proxy:
+                async with await s_telepath.openurl('aha://0.cell...') as proxy:
                     self.nn(await proxy.getCellIden())
 
                 # force a reconnect...
-                proxy = await cryo.ahaclient.proxy(timeout=2)
+                proxy = await cell.ahaclient.proxy(timeout=2)
                 async with aha.waiter(2 * replaymult, 'aha:svcadd'):
                     await proxy.fini()
 
-                async with await s_telepath.openurl('aha://cryo...') as proxy:
+                async with await s_telepath.openurl('aha://cell...') as proxy:
                     self.nn(await proxy.getCellIden())
 
                 # force the service into passive mode...
                 async with aha.waiter(3 * replaymult, 'aha:svcdown', 'aha:svcadd', timeout=6):
-                    await cryo.setCellActive(False)
+                    await cell.setCellActive(False)
 
                 with self.raises(s_exc.NoSuchName):
-                    async with await s_telepath.openurl('aha://cryo...') as proxy:
+                    async with await s_telepath.openurl('aha://cell...') as proxy:
                         pass
 
-                async with await s_telepath.openurl('aha://0.cryo...') as proxy:
+                async with await s_telepath.openurl('aha://0.cell...') as proxy:
                     self.nn(await proxy.getCellIden())
 
                 async with aha.waiter(1 * replaymult, 'aha:svcadd', timeout=6):
-                    await cryo.setCellActive(True)
+                    await cell.setCellActive(True)
 
-                async with await s_telepath.openurl('aha://cryo...') as proxy:
+                async with await s_telepath.openurl('aha://cell...') as proxy:
                     self.nn(await proxy.getCellIden())
 
             wait01 = aha.waiter(2 * replaymult, 'aha:svcadd')
 
-            conf = {'aha:provision': await aha.addAhaSvcProv('0.cryo')}
-            async with self.getTestCryo(conf=conf) as cryo:
+            conf = {'aha:provision': await aha.addAhaSvcProv('0.cell')}
+            async with self.getTestCell(ctor=PathAwareCell, conf=conf) as cell:
 
-                info = await cryo.getCellInfo()
+                info = await cell.getCellInfo()
+                celliden = info['cell']['iden']
 
-                self.eq(info['cell']['aha'], {'name': '0.cryo', 'leader': 'cryo', 'network': 'synapse'})
+                self.eq(info['cell']['aha'], {'name': '0.cell', 'leader': 'cell', 'network': 'synapse'})
 
                 await wait01.wait(timeout=2)
 
-                async with await s_telepath.openurl('aha://cryo.synapse') as proxy:
-                    self.nn(await proxy.getCellIden())
+                async with await s_telepath.openurl('aha://cell.synapse') as proxy:
+                    self.eq(celliden, await proxy.getCellIden())
 
-                async with await s_telepath.openurl('aha://0.cryo.synapse') as proxy:
-                    self.nn(await proxy.getCellIden())
-                    await proxy.puts('hehe', ('hehe', 'haha'))
+                async with await s_telepath.openurl('aha://0.cell.synapse') as proxy:
+                    self.eq(celliden, await proxy.getCellIden())
 
-                async with await s_telepath.openurl('aha://0.cryo.synapse/*/hehe') as proxy:
-                    self.nn(await proxy.iden())
+                async with await s_telepath.openurl('aha://0.cell.synapse/*/hehe/haha') as proxy:
+                    self.eq(celliden, await proxy.getCellIden())
+                    self.eq(('hehe', 'haha'), await proxy.getTestPath())
 
                 async with aha.getLocalProxy() as ahaproxy:
 
                     svcs = [x async for x in ahaproxy.getAhaSvcs('synapse')]
                     self.len(2, svcs)
                     names = [s['name'] for s in svcs]
-                    self.sorteq(('cryo.synapse', '0.cryo.synapse'), names)
+                    self.sorteq(('cell.synapse', '0.cell.synapse'), names)
 
                     self.none(await ahaproxy.getCaCert('vertex.link'))
                     cacert0 = await ahaproxy.genCaCert('vertex.link')
@@ -278,7 +293,7 @@ class AhaTest(s_test.SynTest):
                     self.eq(cacert0, cacert1)
                     self.eq(cacert0, await ahaproxy.getCaCert('vertex.link'))
 
-                    csrpem = cryo.certdir.genHostCsr('cryo.vertex.link').decode()
+                    csrpem = cell.certdir.genHostCsr('cell.vertex.link').decode()
 
                     hostcert00 = await ahaproxy.signHostCsr(csrpem)
                     hostcert01 = await ahaproxy.signHostCsr(csrpem)
@@ -287,7 +302,7 @@ class AhaTest(s_test.SynTest):
                     self.nn(hostcert01)
                     self.ne(hostcert00, hostcert01)
 
-                    csrpem = cryo.certdir.genUserCsr('visi@vertex.link').decode()
+                    csrpem = cell.certdir.genUserCsr('visi@vertex.link').decode()
 
                     usercert00 = await ahaproxy.signUserCsr(csrpem)
                     usercert01 = await ahaproxy.signUserCsr(csrpem)
@@ -310,7 +325,7 @@ class AhaTest(s_test.SynTest):
                     self.eq(info.get('status'), 'ok')
                     result = info.get('result')
                     self.len(2, result)
-                    self.eq({'0.cryo.synapse', 'cryo.synapse'},
+                    self.eq({'0.cell.synapse', 'cell.synapse'},
                             {svcinfo.get('name') for svcinfo in result})
 
                 async with sess.get(svcsurl, json={'network': 'synapse'}) as resp:
@@ -319,7 +334,7 @@ class AhaTest(s_test.SynTest):
                     self.eq(info.get('status'), 'ok')
                     result = info.get('result')
                     self.len(2, result)
-                    self.eq({'0.cryo.synapse', 'cryo.synapse'},
+                    self.eq({'0.cell.synapse', 'cell.synapse'},
                             {svcinfo.get('name') for svcinfo in result})
 
                 async with sess.get(svcsurl, json={'network': 'newp'}) as resp:
@@ -351,10 +366,10 @@ class AhaTest(s_test.SynTest):
                     self.eq(info.get('code'), 'AuthDeny')
 
             async with aha.getLocalProxy() as ahaproxy:
-                await ahaproxy.delAhaSvc('cryo', network='synapse')
-                await ahaproxy.delAhaSvc('0.cryo', network='synapse')
-                self.none(await ahaproxy.getAhaSvc('cryo.synapse'))
-                self.none(await ahaproxy.getAhaSvc('0.cryo.synapse'))
+                await ahaproxy.delAhaSvc('cell', network='synapse')
+                await ahaproxy.delAhaSvc('0.cell', network='synapse')
+                self.none(await ahaproxy.getAhaSvc('cell.synapse'))
+                self.none(await ahaproxy.getAhaSvc('0.cell.synapse'))
                 self.len(0, [s async for s in ahaproxy.getAhaSvcs()])
 
                 with self.raises(s_exc.BadArg):
@@ -431,24 +446,24 @@ class AhaTest(s_test.SynTest):
         async with self.getTestAha() as aha:
 
             wait00 = aha.waiter(1, 'aha:svcadd')
-            conf = {'aha:provision': await aha.addAhaSvcProv('0.cryo')}
+            conf = {'aha:provision': await aha.addAhaSvcProv('0.cell')}
 
-            async with self.getTestCryo(conf=conf) as cryo:
+            async with self.getTestCell(conf=conf) as cell:
 
                 self.true(await wait00.wait(timeout=2))
 
-                async with await s_telepath.openurl('aha://0.cryo...') as proxy:
+                async with await s_telepath.openurl('aha://0.cell...') as proxy:
                     self.nn(await proxy.getCellIden())
 
-                proxy = await cryo.ahaclient.proxy()
+                proxy = await cell.ahaclient.proxy()
 
                 # avoid race to notify client...
-                async with cryo.ahaclient.waiter(1, 'tele:client:linkloop', timeout=2):
+                async with cell.ahaclient.waiter(1, 'tele:client:linkloop', timeout=2):
                     await aha.fini()
                     self.true(await proxy.waitfini(timeout=10))
 
                 with self.raises(asyncio.TimeoutError):
-                    await cryo.ahaclient.proxy(timeout=0.1)
+                    await cell.ahaclient.proxy(timeout=0.1)
 
     async def test_lib_aha_onlink_fail(self):
 
@@ -463,12 +478,12 @@ class AhaTest(s_test.SynTest):
                 aha.testerr = True
                 wait00 = aha.waiter(1, 'aha:svcadd')
 
-                conf = {'aha:provision': await aha.addAhaSvcProv('0.cryo')}
-                async with self.getTestCryo(conf=conf) as cryo:
+                conf = {'aha:provision': await aha.addAhaSvcProv('0.cell')}
+                async with self.getTestCell(conf=conf) as cell:
 
                     self.none(await wait00.wait(timeout=2))
 
-                    svc = await aha.getAhaSvc('0.cryo...')
+                    svc = await aha.getAhaSvc('0.cell...')
                     self.none(svc)
 
                     wait01 = aha.waiter(1 * replaymult, 'aha:svcadd')
@@ -476,11 +491,11 @@ class AhaTest(s_test.SynTest):
 
                     self.nn(await wait01.wait(timeout=2))
 
-                    svc = await aha.getAhaSvc('0.cryo...')
+                    svc = await aha.getAhaSvc('0.cell...')
                     self.nn(svc)
                     self.nn(svc.get('svcinfo', {}).get('online'))
 
-                    async with await s_telepath.openurl('aha://0.cryo...') as proxy:
+                    async with await s_telepath.openurl('aha://0.cell...') as proxy:
                         self.nn(await proxy.getCellIden())
 
     async def test_lib_aha_bootstrap(self):
