@@ -276,6 +276,16 @@ class SnapTest(s_t_utils.SynTest):
             self.len(1, await alist(view1.eval('inet:ipv4 +:asn=42')))
             self.len(1, await alist(view1.eval('inet:ipv4 +#woot')))
 
+            await view0.core.nodes('[ inet:ipv4=1.1.1.1 :asn=5 ]')
+            nodes = await view0.core.nodes('inet:ipv4=1.1.1.1 [ :asn=6 ]', opts={'view': view1.iden})
+
+            await view0.core.nodes('inet:ipv4=1.1.1.1 | delnode')
+            edits = await nodes[0]._getPropDelEdits('asn')
+
+            root = view0.core.auth.rootuser
+            async with await view1.snap(user=root) as snap:
+                await snap.applyNodeEdit((nodes[0].buid, 'inet:ipv4', edits))
+
     async def test_cortex_lift_layers_bad_filter(self):
         '''
         Test a two layer cortex where a lift operation gives the wrong result
@@ -330,6 +340,19 @@ class SnapTest(s_t_utils.SynTest):
             self.len(1, await alist(view0.eval('[ inet:ipv4=1.2.3.4 :asn=99 ]')))
             self.len(0, await alist(view1.eval('inet:ipv4:asn=99')))
 
+            self.len(1, await alist(view0.eval('[ inet:ipv4=1.2.3.5 :asn=43 ]')))
+            self.len(2, await alist(view1.eval('inet:ipv4:asn')))
+
+            await view0.core.addTagProp('score', ('int', {}), {})
+
+            self.len(1, await alist(view1.eval('inet:ipv4=1.2.3.4 [ +#foo:score=42 ]')))
+            self.len(1, await alist(view0.eval('inet:ipv4=1.2.3.4 [ +#foo:score=42 ]')))
+            self.len(1, await alist(view0.eval('inet:ipv4=1.2.3.4 [ +#foo:score=99 ]')))
+            self.len(1, await alist(view0.eval('inet:ipv4=1.2.3.5 [ +#foo:score=43 ]')))
+
+            nodes = await alist(view1.eval('#foo:score'))
+            self.len(2, await alist(view1.eval('#foo:score')))
+
     async def test_cortex_lift_bytype(self):
         async with self.getTestCore() as core:
             await core.nodes('[ inet:dns:a=(vertex.link, 1.2.3.4) ]')
@@ -415,6 +438,10 @@ class SnapTest(s_t_utils.SynTest):
 
             self.len(1, await view0.nodes('[ test:int=10 +#woot:score=40 ]'))
 
+            self.len(1, await view0.nodes('[ test:int=20 +#woot:score=10 ]'))
+            self.len(1, await view1.nodes('[ test:int=20 +#foo:score=10 ]'))
+            self.len(2, await view1.nodes('#woot:score'))
+
     async def test_cortex_lift_layers_ordering(self):
 
         async with self._getTestCoreMultiLayer() as (view0, view1):
@@ -561,7 +588,10 @@ class SnapTest(s_t_utils.SynTest):
     async def test_snap_editor(self):
 
         async with self.getTestCore() as core:
-            nodes = await core.nodes('[ media:news=63381924986159aff183f0c85bd8ebad +(refs)> {[ inet:fqdn=vertex.link ]} ]')
+
+            await core.nodes('$lib.model.ext.addTagProp(test, (str, ({})), ({}))')
+            await core.nodes('[ media:news=63381924986159aff183f0c85bd8ebad +(refs)> {[ inet:fqdn=vertex.link ]} +#foo ]')
+
             root = core.auth.rootuser
             async with await core.view.snap(user=root) as snap:
                 async with snap.getEditor() as editor:
@@ -571,13 +601,65 @@ class SnapTest(s_t_utils.SynTest):
                     self.len(0, editor.getNodeEdits())
 
                     self.true(await news.addEdge('pwns', s_common.ehex(fqdn.buid)))
+                    self.false(await news.addEdge('pwns', s_common.ehex(fqdn.buid)))
                     nodeedits = editor.getNodeEdits()
                     self.len(1, nodeedits)
                     self.len(1, nodeedits[0][2])
 
+                    self.true(await news.delEdge('pwns', s_common.ehex(fqdn.buid)))
+                    nodeedits = editor.getNodeEdits()
+                    self.len(0, nodeedits)
+
+                    self.true(await news.addEdge('pwns', s_common.ehex(fqdn.buid)))
+                    nodeedits = editor.getNodeEdits()
+                    self.len(1, nodeedits)
+                    self.len(1, nodeedits[0][2])
+
+                    self.false(await news.hasData('foo'))
+                    await news.setData('foo', 'bar')
+                    self.true(await news.hasData('foo'))
+
+                    self.false(news.hasTagProp('foo', 'test'))
+                    await news.setTagProp('foo', 'test', 'bar')
+                    self.true(news.hasTagProp('foo', 'test'))
+
+                async with snap.getEditor() as editor:
+                    news = await editor.addNode('media:news', '63381924986159aff183f0c85bd8ebad')
+
+                    self.true(await news.delEdge('pwns', s_common.ehex(fqdn.buid)))
+                    self.false(await news.delEdge('pwns', s_common.ehex(fqdn.buid)))
+                    nodeedits = editor.getNodeEdits()
+                    self.len(1, nodeedits)
+                    self.len(1, nodeedits[0][2])
+
+                    self.true(await news.addEdge('pwns', s_common.ehex(fqdn.buid)))
+                    nodeedits = editor.getNodeEdits()
+                    self.len(0, nodeedits)
+
+                    snap.strict = False
+                    self.false(await news.addEdge(1, s_common.ehex(fqdn.buid)))
+                    self.false(await news.addEdge('pwns', 1))
+                    self.false(await news.addEdge('pwns', 'bar'))
+                    self.false(await news.delEdge(1, s_common.ehex(fqdn.buid)))
+                    self.false(await news.delEdge('pwns', 1))
+                    self.false(await news.delEdge('pwns', 'bar'))
+
+                    self.true(await news.hasData('foo'))
+
+                    self.true(news.hasTagProp('foo', 'test'))
+
             self.len(1, await core.nodes('media:news -(pwns)> *'))
 
-            self.len(1, await core.nodes('[ inet:dns:soa=(lol,) :fqdn=vertex.link ]'))
-            self.len(1, await core.nodes('inet:dns:soa=(lol,) [ :fqdn=vertex.link ]'))
+            self.len(1, await core.nodes('[ test:ro=foo :writeable=hehe :readable=haha ]'))
+            self.len(1, await core.nodes('test:ro=foo [ :readable = haha ]'))
             with self.raises(s_exc.ReadOnlyProp):
-                await core.nodes('inet:dns:soa=(lol,) [ :fqdn=woot.com ]')
+                await core.nodes('test:ro=foo [ :readable=newp ]')
+
+    async def test_snap_subs_depth(self):
+
+        async with self.getTestCore() as core:
+            fqdn = '.'.join(['x' for x in range(300)]) + '.foo.com'
+            q = f'[ inet:fqdn="{fqdn}"]'
+            nodes = await core.nodes(q)
+            self.len(1, nodes)
+            self.eq(nodes[0].get('zone'), 'foo.com')
