@@ -1,9 +1,9 @@
 import copy
-import json
 
 import synapse.exc as s_exc
 import synapse.common as s_common
 
+import synapse.lib.json as s_json
 import synapse.lib.stormlib.stix as s_stix
 
 import synapse.tests.utils as s_test
@@ -39,12 +39,12 @@ class StormLibStixTest(s_test.SynTest):
     def getTestBundle(self, name):
         path = self.getTestFilePath('stix_export', name)
         with open(path, 'r') as fd:
-            return json.load(fd)
+            return s_json.load(fd)
 
     def setTestBundle(self, name, bund):
         path = self.getTestFilePath('stix_export', name)
         with open(path, 'w') as fd:
-            json.dump(bund, fd, sort_keys=True, indent=2)
+            s_json.dump(bund, fd, sort_keys=True, indent=True)
 
     def reqValidStix(self, item):
         resp = s_stix.validateStix(item)
@@ -188,7 +188,7 @@ class StormLibStixTest(s_test.SynTest):
             self.isin('Error validating bundle', resp.get('mesg'))
 
             self.len(14, bund.get('objects'))
-            self.isin(s_stix.SYN_STIX_EXTENSION_ID, json.dumps(bund))
+            self.isin(s_stix.SYN_STIX_EXTENSION_ID, s_json.dumps(bund).decode())
             nodes = await core.nodes('yield $lib.stix.lift($bundle)', {'vars': {'bundle': bund}})
             self.len(10, nodes)
 
@@ -217,7 +217,7 @@ class StormLibStixTest(s_test.SynTest):
             self.reqValidStix(bund_noext)
             nodes = await core.nodes('yield $lib.stix.lift($bundle)', {'vars': {'bundle': bund_noext}})
             self.len(0, nodes)
-            self.notin(s_stix.SYN_STIX_EXTENSION_ID, json.dumps(bund_noext))
+            self.notin(s_stix.SYN_STIX_EXTENSION_ID, s_json.dumps(bund_noext).decode())
 
             # test some sad paths...
             self.none(await core.callStorm('return($lib.stix.export.bundle().add($lib.true))'))
