@@ -227,6 +227,7 @@ class BaseTest(s_t_utils.SynTest):
                     :name="FOO Bar"
                     :type=osint
                     :url="https://foo.bar/index.html"
+                    :ingest:cursor="Woot Woot "
                     :ingest:latest=20241205
                     :ingest:offset=17
                 ]
@@ -238,6 +239,7 @@ class BaseTest(s_t_utils.SynTest):
             self.eq(sorc.get('name'), 'foo bar')
             self.eq(sorc.get('url'), 'https://foo.bar/index.html')
             self.eq(sorc.get('ingest:offset'), 17)
+            self.eq(sorc.get('ingest:cursor'), 'Woot Woot ')
             self.eq(sorc.get('ingest:latest'), 1733356800000)
 
             valu = (sorc.ndef[1], ('inet:fqdn', 'woot.com'))
@@ -338,8 +340,7 @@ class BaseTest(s_t_utils.SynTest):
                 'tel:mob:telem:cell:carrier', 'tel:mob:telem:imsi', 'tel:mob:telem:imei',
                 'tel:mob:telem:phone', 'tel:mob:telem:mac', 'tel:mob:telem:ipv4',
                 'tel:mob:telem:ipv6', 'tel:mob:telem:wifi', 'tel:mob:telem:wifi:ssid',
-                'tel:mob:telem:wifi:bssid', 'tel:mob:telem:adid', 'tel:mob:telem:aaid',
-                'tel:mob:telem:idfa', 'tel:mob:telem:name', 'tel:mob:telem:email',
+                'tel:mob:telem:wifi:bssid', 'tel:mob:telem:name', 'tel:mob:telem:email',
                 'tel:mob:telem:app', 'tel:mob:telem:data',
                 'inet:http:request:response:time', 'inet:http:request:response:code',
                 'inet:http:request:response:reason', 'inet:http:request:response:body',
@@ -412,3 +413,35 @@ class BaseTest(s_t_utils.SynTest):
             self.eq('bottles.', nodes[0].get('type'))
             self.eq(1706832000000, nodes[0].get('time'))
             self.len(1, await core.nodes('meta:aggregate -> meta:aggregate:type:taxonomy'))
+
+    async def test_model_feed(self):
+
+        async with self.getTestCore() as core:
+            nodes = await core.nodes('''[
+                meta:feed=*
+                    :name="woot (foo bar baz)"
+                    :type=foo.bar.baz
+                    :source={[ meta:source=* :name=woot ]}
+                    :url=https://v.vtx.lk/slack
+                    :query="Hi There"
+                    :opts=({"foo": "bar"})
+                    :period=(2024,2025)
+                    :latest=2025
+                    :offset=17
+                    :cursor=FooBar
+            ]''')
+            self.len(1, nodes)
+            self.nn(nodes[0].get('source'))
+
+            self.eq(nodes[0].get('name'), 'woot (foo bar baz)')
+            self.eq(nodes[0].get('type'), 'foo.bar.baz.')
+            self.eq(nodes[0].get('url'), 'https://v.vtx.lk/slack')
+            self.eq(nodes[0].get('query'), 'Hi There')
+            self.eq(nodes[0].get('opts'), {"foo": "bar"})
+            self.eq(nodes[0].get('period'), (1704067200000, 1735689600000))
+            self.eq(nodes[0].get('latest'), 1735689600000)
+            self.eq(nodes[0].get('offset'), 17)
+            self.eq(nodes[0].get('cursor'), 'FooBar')
+
+            self.len(1, await core.nodes('meta:feed -> meta:source +:name=woot'))
+            self.len(1, await core.nodes('meta:feed -> meta:feed:type:taxonomy'))
