@@ -3,6 +3,7 @@ import logging
 import synapse.exc as s_exc
 import synapse.common as s_common
 import synapse.lib.chop as s_chop
+import synapse.lib.time as s_time
 import synapse.tests.utils as s_t_utils
 
 logger = logging.getLogger(__name__)
@@ -325,6 +326,15 @@ class RiskModelTest(s_t_utils.SynTest):
             self.len(1, await core.nodes('risk:alert :service:platform -> inet:service:platform'))
             self.len(1, await core.nodes('risk:alert :service:instance -> inet:service:instance'))
 
+            opts = {'vars': {'ndef': nodes[0].ndef[1]}}
+            nodes = await core.nodes('risk:alert=$ndef [ :updated=20251003 ]', opts=opts)
+            self.len(1, nodes)
+            self.eq(s_time.parse('20251003'), nodes[0].get('updated'))
+
+            self.len(1, await core.nodes('[ risk:alert=({"name": "bazfaz"}) +(about)> {[ file:bytes=* :name=alert.txt]} ]'))
+            self.len(1, fnode := await core.nodes('risk:alert=({"name": "bazfaz"}) -(about)> file:bytes'))
+            self.eq(fnode[0].get('name'), 'alert.txt')
+
             nodes = await core.nodes('''[
                     risk:compromise=*
                     :vector=*
