@@ -1,11 +1,8 @@
 import os
 import re
-import sys
 import copy
 import gzip
 import pprint
-import asyncio
-import argparse
 import datetime
 import tempfile
 import textwrap
@@ -19,6 +16,7 @@ import synapse.exc as s_exc
 import synapse.common as s_common
 import synapse.cortex as s_cortex
 
+import synapse.lib.cmd as s_cmd
 import synapse.lib.output as s_output
 import synapse.lib.autodoc as s_autodoc
 import synapse.lib.schemas as s_schemas
@@ -122,7 +120,11 @@ class ModelDiffer:
                 deprecated_edges[edge] = curinfo
                 continue
 
-            # TODO - Support changes to the edges?
+            if oldinfo.get('doc') != curinfo.get('doc'):
+                updated_edges[edge] = curinfo
+                continue
+
+            # TODO - Support additional changes to the edges?
             assert False, f'A change was found for the edge: {edge}'
 
         if updated_edges:
@@ -227,12 +229,11 @@ class ModelDiffer:
 
                 if nkeys - okeys:
                     # We've added a key to the prop def.
-                    raise s_exc.NoSuchImpl(mesg='Have not implemented support for a prop def having a key added')
+                    updated_props[prop] = {'type': 'addkey', 'keys': list(nkeys - okeys)}
 
                 if okeys - nkeys:
                     # We've removed a key from the prop def.
                     updated_props[prop] = {'type': 'delkey', 'keys': list(okeys - nkeys)}
-                    continue
 
                 # Check if type change happened, we'll want to document that.
                 ctyp = cpinfo.get('type')
@@ -334,12 +335,11 @@ class ModelDiffer:
 
                 if nkeys - okeys:
                     # We've added a key to the prop def.
-                    raise s_exc.NoSuchImpl(mesg='Have not implemented support for a prop def having a key added')
+                    updated_props[prop] = {'type': 'addkey', 'keys': list(nkeys - okeys)}
 
                 if okeys - nkeys:
                     # We've removed a key from the prop def.
                     updated_props[prop] = {'type': 'delkey', 'keys': list(okeys - nkeys)}
-                    continue
 
                 # Check if type change happened, we'll want to document that.
                 ctyp = cpinfo.get('type')
@@ -456,7 +456,7 @@ def _getModelFile(fp: str) -> dict | None:
         ref_modl = s_common.yamlloads(large_bytz)
     return ref_modl
 
-async def gen(opts: argparse.Namespace,
+async def gen(opts: s_cmd.argparse.Namespace,
               outp: s_output.OutPut):
 
     name = opts.name
@@ -474,7 +474,7 @@ async def gen(opts: argparse.Namespace,
     if opts.verbose:
         outp.printf('Validating data against schema')
 
-    s_schemas._reqChanglogSchema(data)
+    s_schemas._reqChangelogSchema(data)
 
     if opts.verbose:
         outp.printf('Saving the following information:')
@@ -639,6 +639,9 @@ def _gen_model_rst(version, model_ref, changes, current_model, outp: s_output.Ou
     # We don't really have a "updated forms" to display since the delta for forms data is really property
     # deltas covered elsewhere.
 
+    # Updated Edges
+    # TODO Add support for updated edges
+
     # Updated Properties
     upd_props = []
     for form, info in updated_forms.items():
@@ -660,6 +663,8 @@ def _gen_model_rst(version, model_ref, changes, current_model, outp: s_output.Ou
                                f' to {pnfo.get("new_type")}.'
                     elif ptyp == 'delkey':
                         mesg = f'The property ``{prop}`` had the ``{pnfo.get("keys")}`` keys removed from its definition.'
+                    elif ptyp == 'addkey':
+                        mesg = f'The property ``{prop}`` had the ``{pnfo.get("keys")}`` keys added to its definition.'
                     else:
                         raise s_exc.NoSuchImpl(mesg=f'pnfo.type={ptyp} not supported.')
                     lines = [
@@ -677,6 +682,8 @@ def _gen_model_rst(version, model_ref, changes, current_model, outp: s_output.Ou
                            f' to {pnfo.get("new_type")}.'
                 elif ptyp == 'delkey':
                     mesg = f'The property ``{prop}`` had the ``{pnfo.get("keys")}`` keys removed from its definition.'
+                elif ptyp == 'addkey':
+                    mesg = f'The property ``{prop}`` had the ``{pnfo.get("keys")}`` keys added to its definition.'
                 else:
                     raise s_exc.NoSuchImpl(mesg=f'pnfo.type={ptyp} not supported.')
 
@@ -797,7 +804,7 @@ def _gen_model_rst(version, model_ref, changes, current_model, outp: s_output.Ou
     return rst
 
 
-async def format(opts: argparse.Namespace,
+async def format(opts: s_cmd.argparse.Namespace,
            outp: s_output.OutPut):
 
     if not regex.match(version_regex, opts.version):
@@ -826,7 +833,7 @@ async def format(opts: argparse.Namespace,
 
         files_processed.append(fp)
 
-        s_schemas._reqChanglogSchema(data)
+        s_schemas._reqChangelogSchema(data)
 
         data.setdefault('prs', [])
         prs = data.get('prs')
@@ -877,34 +884,8 @@ async def format(opts: argparse.Namespace,
     modeldiff = False
     clean_vers_ref = opts.version.replace(".", "_")
     model_rst_ref = f'userguide_model_{clean_vers_ref}'
-    for key, header in s_schemas._changelogTypes.items():
-        dataz = entries.get(key)
-        if dataz:
-            text = text + f'\n{header}\n{"-" * len(header)}'
-            dataz.sort(key=lambda x: x.get('prs'))
-            for data in dataz:
-                desc = data.get('desc')  # type: str
-                desc_lines = desc.splitlines()
-                for i, chunk in enumerate(desc_lines):
-                    if i == 0:
-                        for line in textwrap.wrap(chunk, initial_indent='- ', subsequent_indent='  ', width=opts.width):
-                            text = f'{text}\n{line}'
-                    else:
-                        text = text + '\n'
-                        for line in textwrap.wrap(chunk, initial_indent='  ', subsequent_indent='  ', width=opts.width):
-                            text = f'{text}\n{line}'
 
-                if not opts.hide_prs:
-                    for pr in data.get('prs'):
-                        text = f'{text}\n  (`#{pr} <https://github.com/vertexproject/synapse/pull/{pr}>`_)'
-            if key == 'migration':
-                text = text + '\n- See :ref:`datamigration` for more information about automatic migrations.'
-            elif key == 'model':
-                text = text + f'\n- See :ref:`{model_rst_ref}` for more detailed model changes.'
-                modeldiff = True
-            text = text + '\n'
-
-    if modeldiff and opts.model_ref:
+    if opts.model_ref:
         # TODO find previous model file automatically?
         if opts.verbose:
             outp.printf(f'Getting reference model from {opts.model_ref}')
@@ -925,6 +906,8 @@ async def format(opts: argparse.Namespace,
         changes = differ.diffModl(outp)
         has_changes = sum([len(v) for v in changes.values()])
         if has_changes:
+            entries['model'].append({'prs': [], 'type': 'skip'})
+            modeldiff = True
             rst = _gen_model_rst(opts.version, model_rst_ref, changes, cur_modl, outp, width=opts.width)
             model_text = rst.getRstText()
             if opts.verbose:
@@ -946,6 +929,35 @@ async def format(opts: argparse.Namespace,
         else:
             outp.printf(f'No model changes detected.')
 
+    for key, header in s_schemas._changelogTypes.items():
+        dataz = entries.get(key)
+        if dataz:
+            text = text + f'\n{header}\n{"-" * len(header)}'
+            dataz.sort(key=lambda x: x.get('prs'))
+            for data in dataz:
+                desc = data.get('desc')  # type: str
+                if desc is None and data.get('type') == 'skip':
+                    continue
+                desc_lines = desc.splitlines()
+                for i, chunk in enumerate(desc_lines):
+                    if i == 0:
+                        for line in textwrap.wrap(chunk, initial_indent='- ', subsequent_indent='  ', width=opts.width):
+                            text = f'{text}\n{line}'
+                    else:
+                        text = text + '\n'
+                        for line in textwrap.wrap(chunk, initial_indent='  ', subsequent_indent='  ', width=opts.width):
+                            text = f'{text}\n{line}'
+
+                if not opts.hide_prs:
+                    for pr in data.get('prs'):
+                        text = f'{text}\n  (`#{pr} <https://github.com/vertexproject/synapse/pull/{pr}>`_)'
+            if key == 'migration':
+                text = text + '\n- See :ref:`datamigration` for more information about automatic migrations.'
+            elif key == 'model':
+                if modeldiff:
+                    text = text + f'\n- See :ref:`{model_rst_ref}` for more detailed model changes.'
+            text = text + '\n'
+
     if opts.rm:
         if opts.verbose:
             outp.printf('Staging file removals in git')
@@ -962,7 +974,7 @@ async def format(opts: argparse.Namespace,
 
     return 0
 
-async def model(opts: argparse.Namespace,
+async def model(opts: s_cmd.argparse.Namespace,
            outp: s_output.OutPut):
 
     if opts.save:
@@ -1003,11 +1015,8 @@ async def model(opts: argparse.Namespace,
             outp.printf(line)
         return 0
 
-async def main(argv, outp=None):
-    if outp is None:
-        outp = s_output.OutPut()
-
-    pars = makeargparser()
+async def main(argv, outp=s_output.stdout):
+    pars = getArgParser(outp)
 
     opts = pars.parse_args(argv)
     if opts.git_dir_check:
@@ -1024,11 +1033,11 @@ async def main(argv, outp=None):
         outp.printf(f'Error running {opts.func}: {traceback.format_exc()}')
     return 1
 
-def makeargparser():
+def getArgParser(outp: s_output.OutPut):
     desc = '''Command line tool to manage changelog entries.
     This tool and any data formats associated with it may change at any time.
     '''
-    pars = argparse.ArgumentParser('synapse.tools.changelog', description=desc)
+    pars = s_cmd.Parser(prog='synapse.tools.changelog', outp=outp, description=desc)
 
     subpars = pars.add_subparsers(required=True,
                                   title='subcommands',
@@ -1045,7 +1054,7 @@ def makeargparser():
                           help='Add the newly created file to the current git staging area.')
     # Hidden name override. Mainly for testing.
     gen_pars.add_argument('-n', '--name', default=None, type=str,
-                          help=argparse.SUPPRESS)
+                          help=s_cmd.argparse.SUPPRESS)
 
     format_pars = subpars.add_parser('format', help='Format existing files into a RST block.')
     format_pars.set_defaults(func=format)
@@ -1087,10 +1096,11 @@ def makeargparser():
                        help='Enable verbose output')
         p.add_argument('--cdir', default='./changes', action='store',
                        help='Directory of changelog files.')
+        # Hidden name override. Mainly for testing.
         p.add_argument('--disable-git-dir-check', dest='git_dir_check', default=True, action='store_false',
-                       help=argparse.SUPPRESS)
+                       help=s_cmd.argparse.SUPPRESS)
 
     return pars
 
 if __name__ == '__main__':  # pragma: no cover
-    sys.exit(asyncio.run(main(sys.argv[1:], s_output.stdout)))
+    s_cmd.exitmain(main)
