@@ -1,3 +1,4 @@
+import synapse.common as s_common
 import synapse.telepath as s_telepath
 
 import synapse.lib.cmd as s_cmd
@@ -24,4 +25,5 @@ async def main(argv, outp=s_output.stdout):
     return 0
 
 if __name__ == '__main__':  # pragma: no cover
+    s_common.deprecated('synapse.tools.cryo.list', curv='2.223.0')
     s_cmd.exitmain(main)
