@@ -213,6 +213,15 @@ def loadPkgProto(path, opticdir=None, no_docs=False, readonly=False):
         gdef['scope'] = 'power-up'
         gdef['power-up'] = pkgname
 
+    inits = pkgdef.get('inits')
+    if inits is not None:
+        lastver = None
+        for initdef in inits.get('versions'):
+            curver = initdef.get('version')
+            if lastver is not None and not curver > lastver:
+                raise s_exc.BadPkgDef(mesg='Init versions must be monotonically increasing.', version=curver)
+            lastver = curver
+
     wflowdir = s_common.genpath(protodir, 'workflows')
     if os.path.isdir(wflowdir):
         pkgdef.setdefault('optic', {})
