@@ -1,8 +1,8 @@
 import os
 import sys
-import json
 import argparse
 
+import synapse.lib.json as s_json
 import synapse.lib.output as s_output
 import synapse.lib.msgpack as s_msgpack
 
@@ -12,11 +12,7 @@ def getArgParser():
     pars.add_argument('paths', nargs='+', help='json files or directories full of json files')
     return pars
 
-def main(argv, outp=None):
-
-    if outp is None:  # pragma: no cover
-        outp = s_output.OutPut()
-
+def main(argv, outp=s_output.stdout):
     pars = getArgParser()
     opts = pars.parse_args(argv)
 
@@ -37,7 +33,7 @@ def main(argv, outp=None):
         with open(path, 'r', encoding='utf8') as fd:
             with open(newp, 'wb') as pk:
                 for line in fd:
-                    item = json.loads(line)
+                    item = s_json.loads(line)
                     pk.write(s_msgpack.en(item))
 
         if opts.rm:
