@@ -1,10 +1,8 @@
-import sys
-import asyncio
 import logging
-import argparse
 
 import synapse.common as s_common
 
+import synapse.lib.cmd as s_cmd
 import synapse.lib.output as s_output
 import synapse.lib.rstorm as s_rstorm
 
@@ -15,7 +13,7 @@ descr = 'An RST pre-processor that allows you to embed storm directives.'
 
 async def main(argv, outp=s_output.stdout):
 
-    pars = argparse.ArgumentParser(prog=prog, description=descr)
+    pars = s_cmd.Parser(prog=prog, outp=outp, description=descr)
     pars.add_argument('rstfile', help='Input RST file with storm directives.')
     pars.add_argument('--save', help='Output file to save (default: stdout)')
 
@@ -32,6 +30,6 @@ async def main(argv, outp=s_output.stdout):
         for line in lines:
             outp.printf(line, addnl=False)
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     s_common.setlogging(logger)
-    sys.exit(asyncio.run(main(sys.argv[1:])))
+    s_cmd.exitmain(main)
